"""KiCad Python code for generating bill of materials in multiple formats."""
# This file is generated automatically from metadata
# File edits may be overwritten!
from kicad_bom.__about__ import (
    __author__,
    __copyright__,
    __email__,
    __license__,
    __description__,
    __url__,
    __version__)

from .kicad_bom import KicadBom, save_all_csv_files
